pub fn scalar_kind(value: &Value) -> Option<ScalarKind>Expand description
The scalar kind of value, or None for an array/object (the guard
does not apply to containers — see cli-shell-config-todo.md 3).
pub fn scalar_kind(value: &Value) -> Option<ScalarKind>The scalar kind of value, or None for an array/object (the guard
does not apply to containers — see cli-shell-config-todo.md 3).