pub struct IniDocument<'a> { /* private fields */ }Expand description
Parsed INI Core v1 source document. The lexer used for semantic loading and source editing is intentionally shared so both paths enforce the same section/key/duplicate rules.
Implementations
Sourceimpl<'a> IniDocument<'a>
impl<'a> IniDocument<'a>
pub fn parse(source: &'a str) -> DocumentResult<Self>