pub fn assert_strict_event(value: &Value) -> Result<(), ProtocolViolation>Expand description
Assert the recommended strict protocol profile without spawning the CLI.
pub fn assert_strict_event(value: &Value) -> Result<(), ProtocolViolation>Assert the recommended strict protocol profile without spawning the CLI.