pub struct InstalledStreamRedirect {
pub stdout_file: Option<PathBuf>,
pub stderr_file: Option<PathBuf>,
/* private fields */
}Expand description
Guard for installed stream redirection.
Keep this value alive for as long as stdout/stderr should stay redirected. On drop it restores the original process fds.
Fields
stdout_file: Option<PathBuf>File receiving stdout bytes, if stdout redirection is enabled.
stderr_file: Option<PathBuf>File receiving stderr bytes, if stderr redirection is enabled.