pub struct StreamRedirectConfig {
pub stdout_file: Option<PathBuf>,
pub stderr_file: Option<PathBuf>,
}Expand description
Resolved process stream redirection configuration.
Fields
stdout_file: Option<PathBuf>File receiving stdout bytes, if stdout redirection is enabled.
stderr_file: Option<PathBuf>File receiving stderr bytes, if stderr redirection is enabled.
Implementations