Module keyed

Module keyed 

KeyedList operations for slug-based array access.

Structs

KeyedList
Declares that an array at prefix is keyed by slug_field.

Functions

add_keyed
Add a new element to a keyed list.
remove_keyed
Remove an element from a keyed list by slug.