Module path

Module path 

The single path grammar used by every traversal operation.

A dot separates segments. \. embeds a dot in a key and \\ embeds a backslash. Every other escape is rejected so a path is reversible.

Functions

join_path
parse_path