pub struct ErrorSpec { /* private fields */ }Expand description
Stable fields that are safe to return to a caller.
Implementations
Sourceimpl ErrorSpec
impl ErrorSpec
Sourcepub fn new(code: impl Into<String>, message: impl Into<String>) -> Self
pub fn new(code: impl Into<String>, message: impl Into<String>) -> Self
Declare a stable error code and public message.
Sourcepub const fn retryable(self, retryable: bool) -> Self
pub const fn retryable(self, retryable: bool) -> Self
Declare whether retrying may succeed without changing the request.
pub fn code(&self) -> &str
pub fn message(&self) -> &str
pub fn hint_value(&self) -> Option<&str>
pub const fn is_retryable(&self) -> bool
Sourcepub fn builder(&self) -> ErrorBuilder
pub fn builder(&self) -> ErrorBuilder
Start an error builder using only catalogued public fields.
Applications may add explicitly selected structured fields to the returned builder. No runtime diagnostic is accepted by this API.
Sourcepub fn event(&self) -> Result<Event, BuildError>
pub fn event(&self) -> Result<Event, BuildError>
Build the strict protocol error event.